# AllowedRoleDto


## Enum

* `ADMIN` (value: `'ADMIN'`)

* `USER` (value: `'USER'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


